This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] gcc: Fix comment typos and formatting, etc.


Hi,

Committed as obvious.

Kazu Hirata

2004-02-27  Kazu Hirata  <kazu@cs.umass.edu>

	* c-decl.c, c-ppoutput.c, combine.c, cppfiles.c, dwarf2out.c,
	expr.c, fold-const.c, gcc.c, haifa-sched.c, loop-iv.c,
	params.def, read-rtl.c, rtl.c, rtlanal.c, toplev.c: Fix
	comment typos and formatting.  Follow spelling conventions.

Index: c-decl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/c-decl.c,v
retrieving revision 1.480
diff -u -r1.480 c-decl.c
--- c-decl.c	26 Feb 2004 23:25:14 -0000	1.480
+++ c-decl.c	27 Feb 2004 07:03:03 -0000
@@ -611,7 +611,7 @@
 	      && DECL_NAME (p)
 	      && !DECL_ARTIFICIAL (p))
 	    warning ("%Junused variable `%D'", p, p);
-	  /* fall through */
+	  /* Fall through.  */
 
 	default:
 	normal:
@@ -1016,7 +1016,7 @@
   if (TREE_CODE (newdecl) == TYPE_DECL)
     {
       if (DECL_IN_SYSTEM_HEADER (newdecl) || DECL_IN_SYSTEM_HEADER (olddecl))
-	return true;  /* allow OLDDECL to continue in use */
+	return true;  /* Allow OLDDECL to continue in use.  */
       
       error ("%Jredefinition of typedef '%D'", newdecl, newdecl);
       locate_old_decl (olddecl, error);
Index: c-ppoutput.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/c-ppoutput.c,v
retrieving revision 1.17
diff -u -r1.17 c-ppoutput.c
--- c-ppoutput.c	18 Feb 2004 22:02:38 -0000	1.17
+++ c-ppoutput.c	27 Feb 2004 07:03:03 -0000
@@ -36,7 +36,7 @@
   const cpp_token *source;	/* Source token for spacing.  */
   int src_line;			/* Line number currently being written.  */
   unsigned char printed;	/* Nonzero if something output at line.  */
-  bool first_time;		/* pp_file_change hasn't been called yet. */
+  bool first_time;		/* pp_file_change hasn't been called yet.  */
 } print;
 
 /* General output routines.  */
Index: combine.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/combine.c,v
retrieving revision 1.413
diff -u -r1.413 combine.c
--- combine.c	21 Feb 2004 18:41:48 -0000	1.413
+++ combine.c	27 Feb 2004 07:03:09 -0000
@@ -1452,7 +1452,7 @@
   int added_sets_1, added_sets_2;
   /* Total number of SETs to put into I3.  */
   int total_sets;
-  /* Nonzero is I2's body now appears in I3.  */
+  /* Nonzero if I2's body now appears in I3.  */
   int i2_is_used;
   /* INSN_CODEs for new I3, new I2, and user of condition code.  */
   int insn_code_number, i2_code_number = 0, other_code_number = 0;
Index: cppfiles.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cppfiles.c,v
retrieving revision 1.203
diff -u -r1.203 cppfiles.c
--- cppfiles.c	18 Feb 2004 22:02:38 -0000	1.203
+++ cppfiles.c	27 Feb 2004 07:03:10 -0000
@@ -109,7 +109,7 @@
   /* If BUFFER above contains the true contents of the file.  */
   bool buffer_valid;
 
-  /* File is a PCH (on return from find_include_file). */
+  /* File is a PCH (on return from find_include_file).  */
   bool pch;
 };
 
Index: dwarf2out.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/dwarf2out.c,v
retrieving revision 1.496
diff -u -r1.496 dwarf2out.c
--- dwarf2out.c	18 Feb 2004 23:57:58 -0000	1.496
+++ dwarf2out.c	27 Feb 2004 07:03:16 -0000
@@ -9873,7 +9873,7 @@
 	  || (bound_attr == DW_AT_lower_bound
 	      && (((is_c_family () || is_java ()) &&  integer_zerop (bound))
 		  || (is_fortran () && integer_onep (bound)))))
-	/* use the default */
+	/* Use the default.  */
 	;
       else
 	add_AT_unsigned (subrange_die, bound_attr, tree_low_cst (bound, 0));
@@ -12882,7 +12882,7 @@
 	  (*targetm.asm_out.internal_label) (asm_out_file, SEPARATE_LINE_CODE_LABEL,
 				     separate_line_info_table_in_use);
 
-	  /* expand the line info table if necessary */
+	  /* Expand the line info table if necessary.  */
 	  if (separate_line_info_table_in_use
 	      == separate_line_info_table_allocated)
 	    {
Index: expr.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/expr.c,v
retrieving revision 1.625
diff -u -r1.625 expr.c
--- expr.c	19 Feb 2004 07:52:51 -0000	1.625
+++ expr.c	27 Feb 2004 07:03:21 -0000
@@ -645,7 +645,7 @@
       if (to_mode == full_mode)
 	return;
 
-      /* else proceed to integer conversions below */
+      /* else proceed to integer conversions below.  */
       from_mode = full_mode;
     }
 
Index: fold-const.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fold-const.c,v
retrieving revision 1.334
diff -u -r1.334 fold-const.c
--- fold-const.c	25 Feb 2004 18:15:52 -0000	1.334
+++ fold-const.c	27 Feb 2004 07:03:25 -0000
@@ -718,7 +718,7 @@
   if (quo_neg)
     neg_double (*lquo, *hquo, lquo, hquo);
 
-  /* compute trial remainder:  rem = num - (quo * den)  */
+  /* Compute trial remainder:  rem = num - (quo * den)  */
   mul_double (*lquo, *hquo, lden_orig, hden_orig, lrem, hrem);
   neg_double (*lrem, *hrem, lrem, hrem);
   add_double (lnum_orig, hnum_orig, *lrem, *hrem, lrem, hrem);
Index: gcc.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gcc.c,v
retrieving revision 1.407
diff -u -r1.407 gcc.c
--- gcc.c	20 Feb 2004 06:46:41 -0000	1.407
+++ gcc.c	27 Feb 2004 07:03:28 -0000
@@ -6493,7 +6493,7 @@
     }
 
 #if defined (OS2) ||defined (HAVE_DOS_BASED_FILE_SYSTEM)
-  /* look again, but case-insensitively this time.  */
+  /* Look again, but case-insensitively this time.  */
   if (cp < compilers)
     for (cp = compilers + n_compilers - 1; cp >= compilers; cp--)
       {
Index: haifa-sched.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/haifa-sched.c,v
retrieving revision 1.239
diff -u -r1.239 haifa-sched.c
--- haifa-sched.c	24 Feb 2004 17:28:28 -0000	1.239
+++ haifa-sched.c	27 Feb 2004 07:03:29 -0000
@@ -1952,7 +1952,7 @@
 
 		      insns_removed++;
 		      if (insns_removed == flag_sched_stalled_insns)
-			/* remove only one insn from Q at a time */
+			/* Remove only one insn from Q at a time.  */
 			return insns_removed;
 		    }
 		}
Index: params.def
===================================================================
RCS file: /cvs/gcc/gcc/gcc/params.def,v
retrieving revision 1.36
diff -u -r1.36 params.def
--- params.def	21 Feb 2004 00:34:46 -0000	1.36
+++ params.def	27 Feb 2004 07:03:31 -0000
@@ -137,7 +137,7 @@
    
    This limit should be at most half of the peeling limits:  loop unroller
    decides to not unroll loops that iterate fewer than 2*number of allowed
-   unrollings and thus we would have loops that are neither peeled or unrooled
+   unrollings and thus we would have loops that are neither peeled or unrolled
    otherwise.  */
 DEFPARAM(PARAM_MAX_UNROLLED_INSNS,
 	 "max-unrolled-insns",
Index: read-rtl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/read-rtl.c,v
retrieving revision 1.20
diff -u -r1.20 read-rtl.c
--- read-rtl.c	6 Jul 2003 09:56:05 -0000	1.20
+++ read-rtl.c	27 Feb 2004 07:03:31 -0000
@@ -630,7 +630,7 @@
 	  if (c != '[')
 	    fatal_expected_char (infile, '[', c);
 
-	  /* add expressions to a list, while keeping a count */
+	  /* Add expressions to a list, while keeping a count.  */
 	  obstack_init (&vector_stack);
 	  while ((c = read_skip_spaces (infile)) && c != ']')
 	    {
Index: rtl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/rtl.c,v
retrieving revision 1.133
diff -u -r1.133 rtl.c
--- rtl.c	6 Feb 2004 20:03:43 -0000	1.133
+++ rtl.c	27 Feb 2004 07:03:31 -0000
@@ -156,7 +156,7 @@
   rtvec rt;
 
   rt = ggc_alloc_rtvec (n);
-  /* clear out the vector */
+  /* Clear out the vector.  */
   memset (&rt->elem[0], 0, n * sizeof (rtx));
 
   PUT_NUM_ELEM (rt, n);
Index: rtlanal.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/rtlanal.c,v
retrieving revision 1.181
diff -u -r1.181 rtlanal.c
--- rtlanal.c	24 Feb 2004 21:45:20 -0000	1.181
+++ rtlanal.c	27 Feb 2004 07:03:33 -0000
@@ -3325,7 +3325,7 @@
   nregs_xmode = hard_regno_nregs[xregno][xmode];
   nregs_ymode = hard_regno_nregs[xregno][ymode];
 
-  /* paradoxical subregs are always valid.  */
+  /* Paradoxical subregs are always valid.  */
   if (offset == 0
       && nregs_ymode > nregs_xmode
       && (GET_MODE_SIZE (ymode) > UNITS_PER_WORD
Index: toplev.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/toplev.c,v
retrieving revision 1.883
diff -u -r1.883 toplev.c
--- toplev.c	24 Feb 2004 23:39:56 -0000	1.883
+++ toplev.c	27 Feb 2004 07:03:35 -0000
@@ -696,7 +696,7 @@
 
 int flag_gcse_sm = 1;
 
-/* Nonzero if we want to perfrom redundant load after store elimination
+/* Nonzero if we want to perform redundant load after store elimination
    in gcse.  */
 
 int flag_gcse_las = 1;


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: loop-iv.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/loop-iv.c,v
retrieving revision 2.3
diff -u -r2.3 loop-iv.c
--- loop-iv.c	24 Feb 2004 23:39:55 -0000	2.3
+++ loop-iv.c	27 Feb 2004 07:03:30 -0000
@@ -34,7 +34,7 @@
    interesting reg, it is now easy to find a reaching definition (there may be
    only one).
 
-   Induction variable is then simply analysed by walking the use-def
+   Induction variable is then simply analyzed by walking the use-def
    chains.
    
    Usage:
@@ -501,7 +501,7 @@
   enum machine_mode mode;
   rtx arg;
 
   /* Extend the constant to extend_mode of the other operand if neccesary.  */
   if (iv0->extend == NIL
       && iv0->mode == iv0->extend_mode
       && iv0->step == const0_rtx
@@ -862,7 +862,7 @@
   return iv->base != NULL_RTX;
 }
 
-/* Analyses operand OP of INSN and stores the result to *IV.  */
+/* Analyzes operand OP of INSN and stores the result to *IV.  */
 
 static bool
 iv_analyze_op (rtx insn, rtx op, struct rtx_iv *iv)
@@ -927,7 +927,7 @@
   return iv_analyze (def_insn, op, iv);
 }
 
-/* Analyses iv DEF defined in INSN and stores the result to *IV.  */
+/* Analyzes iv DEF defined in INSN and stores the result to *IV.  */
 
 bool
 iv_analyze (rtx insn, rtx def, struct rtx_iv *iv)
@@ -1746,7 +1746,7 @@
 }
 
 /* Transforms IV0 and IV1 compared by COND so that they are both compared as
-   subregs of the same mode if possible (sometimes it is neccesary to add
+   subregs of the same mode if possible (sometimes it is necessary to add
    some assumptions to DESC).  */
 
 static bool
@@ -2082,7 +2082,7 @@
 		 obviously if the test for overflow during that transformation
 		 passed, we cannot overflow here.  Most importantly any
 		 loop with sharp end condition and step 1 falls into this
-		 cathegory, so handling this case specially is definitely
+		 category, so handling this case specially is definitely
 		 worth the troubles.  */
 	      may_xform = const_true_rtx;
 	    }
@@ -501,7 +501,7 @@
   rtx arg;
 
-  /* Extend the constant to extend_mode of the other operand if neccesary.  */
+  /* Extend the constant to extend_mode of the other operand if necessary.  */
   if (iv0->extend == NIL
       && iv0->mode == iv0->extend_mode